@@ -5,8 +5,10 @@ from nibiru.proto.vpool.v1 import query_pb2 as vpool_type
 from nibiru.proto.vpool.v1 import query_pb2_grpc as vpool_query
 from nibiru.proto.vpool.v1.vpool_pb2 import Direction as pbDirection
 
+from .util import deserialize
 
-class VPool:
+
+class VpoolQueryClient:
     """
     VPool allows to query the endpoints made available by the Nibiru Chain's VPOOL module.
     """
@@ -16,18 +18,18 @@ class VPool:
 
     def reserve_assets(self, pair: str):
         req = vpool_type.QueryReserveAssetsRequest(pair=pair)
-        return self.api.ReserveAssets(req)
+        return deserialize(self.api.ReserveAssets(req))
 
     def all_pools(self):
         req = vpool_type.QueryAllPoolsRequest()
-        return self.api.AllPools(req)
+        return deserialize(self.api.AllPools(req))
 
     def base_asset_price(self, pair: str, direction: Direction, base_asset_amount: str):
-        dir = pbDirection.DIRECTION_UNSPECIFIED
+        dir_pb = pbDirection.DIRECTION_UNSPECIFIED
         if direction == Direction.ADD:
-            dir = pbDirection.ADD_TO_POOL
+            dir_pb = pbDirection.ADD_TO_POOL
         elif direction == Direction.REMOVE:
-            dir = pbDirection.REMOVE_FROM_POOL
+            dir_pb = pbDirection.REMOVE_FROM_POOL
 
-        req = vpool_type.QueryBaseAssetPriceRequest(pair=pair, direction=dir, base_asset_amount=base_asset_amount)
-        return self.api.BaseAssetPrice(req)
+        req = vpool_type.QueryBaseAssetPriceRequest(pair=pair, direction=dir_pb, base_asset_amount=base_asset_amount)
+        return deserialize(self.api.BaseAssetPrice(req))
