@@ -1,9 +1,11 @@
+import json
 import logging
 from copy import deepcopy
 
 from google.protobuf import message
-from grpc import RpcError
-from nibiru.client import Client
+from google.protobuf.json_format import MessageToDict
+
+from nibiru.client import GrpcClient
 from nibiru.common import TxConfig, TxType
 from nibiru.composer import Composer
 from nibiru.constant import GAS_PRICE
@@ -12,11 +14,10 @@ from nibiru.network import Network
 from nibiru.proto.cosmos.base.abci.v1beta1 import abci_pb2 as abci_type
 from nibiru.transaction import Transaction
 from nibiru.wallet import PrivateKey
-from loguru import logger
 
 
-class Tx:
-    def __init__(self, priv_key: PrivateKey, network: Network, client: Client, config: TxConfig):
+class BaseTxClient:
+    def __init__(self, priv_key: PrivateKey, network: Network, client: GrpcClient, config: TxConfig):
         self.priv_key = priv_key
         self.network = network
         self.client = client
@@ -83,6 +84,10 @@ class Tx:
                 address.decrease_sequence()
                 raise TxError(tx_output.raw_log)
 
+            tx_output = MessageToDict(tx_output)
+
+            # Convert raw log into a dictionary
+            tx_output["rawLog"] = json.loads(tx_output.get("rawLog", "{}"))
             return tx_output
 
         except SimulationError as err:
