@@ -1,22 +1,16 @@
 from typing import List
 
-from nibiru.common import PoolAsset, Coin
+from nibiru.common import Coin, PoolAsset
+from nibiru.proto.cosmos.base.abci.v1beta1 import abci_pb2 as abci_type
 from nibiru.proto.dex.v1 import pool_pb2 as pool_tx_pb
 from nibiru.proto.dex.v1 import tx_pb2 as dex_tx_pb
-from nibiru.utils import to_sdk_dec
-from nibiru.proto.cosmos.base.abci.v1beta1 import abci_pb2 as abci_type
 
-from .common import Tx
+from .common import BaseTxClient
 
 
-class Dex(Tx):
+class DexTxClient(BaseTxClient):
     def create_pool(
-        self,
-        creator: str,
-        swap_fee: float,
-        exit_fee: float,
-        assets: List[PoolAsset],
-        **kwargs
+        self, creator: str, swap_fee: float, exit_fee: float, assets: List[PoolAsset], **kwargs
     ) -> abci_type.TxResponse:
         """
         Create a pool using the assets specified
@@ -31,22 +25,21 @@ class Dex(Tx):
             abci_type.TxResponse: The output of the transaction
         """
         pool_assets = [
-            pool_tx_pb.PoolAsset(
-                token=a.token._generate_proto_object(), weight=str(int(a.weight*1e6))
-            ) for a in assets
+            pool_tx_pb.PoolAsset(token=a.token._generate_proto_object(), weight=str(int(a.weight * 1e6)))
+            for a in assets
         ]
 
         swap_fee_dec = str(int(swap_fee * 1e18))
         exit_fee_dec = str(int(exit_fee * 1e18))
 
-        msg= dex_tx_pb.MsgCreatePool(
+        msg = dex_tx_pb.MsgCreatePool(
             creator=creator,
             pool_params=pool_tx_pb.PoolParams(swap_fee=swap_fee_dec, exit_fee=exit_fee_dec),
             pool_assets=pool_assets,
         )
         return super().execute_msg(msg, **kwargs)
 
-    def join_pool(self, sender: str, pool_id: int, tokens: List[Coin], **kwargs)->abci_type.TxResponse:
+    def join_pool(self, sender: str, pool_id: int, tokens: List[Coin], **kwargs) -> abci_type.TxResponse:
         """
         Join a pool using the specified tokens
 
@@ -65,7 +58,7 @@ class Dex(Tx):
         )
         return super().execute_msg(msg, **kwargs)
 
-    def exit_pool(self, sender: str, pool_id: int, pool_shares: Coin, **kwargs)->abci_type.TxResponse:
+    def exit_pool(self, sender: str, pool_id: int, pool_shares: Coin, **kwargs) -> abci_type.TxResponse:
         """
         Exit a pool using the specified pool shares
 
@@ -84,7 +77,7 @@ class Dex(Tx):
         )
         return super().execute_msg(msg, **kwargs)
 
-    def swap_assets(self, sender: str, pool_id: int, token_in: Coin, token_out_denom, **kwargs)->abci_type.TxResponse:
+    def swap_assets(self, sender: str, pool_id: int, token_in: Coin, token_out_denom, **kwargs) -> abci_type.TxResponse:
         """
         Swap the assets provided for the denom specified
 
